@@ -12,12 +12,15 @@ use Log::Log4perl qw(:easy);
 use DateTime;
 use Data::Dumper;
 use List::Util qw/shuffle/;
-#use IPC::Cmd qw/can_run/;
+# use IPC::Cmd qw/can_run/;
 
 use Moose;
 extends 'HPC::Runner';
 with 'MooseX::SimpleConfig';
 
+# For pretty man pages!
+$ENV{TERM}='xterm-256color';
+
 =head1 NAME
 
 HPC::Runner::Slurm - Job Submission to Slurm
@@ -28,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.35';
+our $VERSION = '2.36';
 
 =head1 SYNOPSIS
 
@@ -82,6 +85,14 @@ This is optional. Paramaters can be passed straight to the command line
 
 has '+configfile' => (
     required => 0,
+    documentation => q{If you get tired of putting all your options on the command line create a config file instead.
+    ---
+    infile: "/path/to/commands/testcommand.in"
+    outdir: "path/to/testdir"
+    module:
+        - "R2"
+        - "shared"
+    }
 );
 
 
@@ -181,6 +192,7 @@ has 'commands_per_node' => (
     isa => 'Str',
     required => 0,
     default => 8,
+    documentation => q{Commands to run on each node. This is not the same as concurrent_commands_per_node!},
 );
 
 =head2 partition
@@ -196,6 +208,7 @@ has 'partition' => (
     isa => 'Str',
     required => 0,
     default => '',
+    documentation => q{Slurm partition to submit jobs to. Defaults to the partition with the most available nodes}
 );
 
 =head2 nodelist
@@ -236,6 +249,7 @@ One is generated here for you, but you can always supply your own with --templat
 =cut
 
 has 'template_file' => (
+    traits => ['NoGetopt'],
     is => 'rw',
     isa => 'Str',
     default => sub {
@@ -275,27 +289,17 @@ EOF
     },
 );
 
-#=head2 procs_per_sbatch
-#
-#Number of processes to use per sbatch. By default this is a conservative number as there is no checking mechanism to see how 'heavy' a job is.
-#
-#=cut
-#
-#has procs_per_sbatch => (
-#    is => 'rw',
-#    isa => 'Int',
-#    default => 4,
-#    required => 0,
-#);
 
 =head2 serial
 Option to run all jobs serially, one after the other, no parallelism
 The default is to use 4 procs
 =cut
+
 has serial => (
     is        => 'rw',
     isa     => 'Bool',
     default => 0,
+    documentation => q{Use this if you wish to run each job run one after another, with each job starting only after the previous has completed successfully}
 );
 
 
@@ -311,6 +315,7 @@ has 'user' => (
     isa => 'Str',
     default => sub { return $ENV{LOGNAME} || $ENV{USER} || getpwuid($<); },
     required => 1,
+    documentation => q{This defaults to your current user ID. This can only be changed if running as an admin user}
 );
 
 =head2 use_threads 
@@ -326,6 +331,7 @@ has 'use_threads' => (
     isa => 'Bool',
     default => 0,
     required => 0,
+    documentation => q{Use threads to run jobs},
 );
 
 =head2 use_processes 
@@ -339,6 +345,7 @@ has 'use_processes' => (
     isa => 'Bool',
     default => 1,
     required => 0,
+    documentation => q{Use processes to run jobs},
 );
 
 =head2 use_gnuparallel 
@@ -352,6 +359,7 @@ has 'use_gnuparallel' => (
     isa => 'Bool',
     default => 0,
     required => 0,
+    documentation => q{Use gnu-parallel to run jobs and manage threads. This is the best option if you do not know how many threads your application uses!}
 );
 
 =head1 Internal Variables
@@ -369,6 +377,7 @@ has 'template' => (
     is => 'rw',
     required => 0,
     default => sub {return Template->new(ABSOLUTE     => 1) },
+#    documentation => q{Path to Slurm template file if you do not wish to use the default}
 );
 
 
